@@ -29,7 +29,7 @@ class AbstractToggleControl():
     if callback:
       toggle_button.connect('toggled', callback, self, *args)
     self.__buttons.append(toggle_button)
-    self.__hbox.pack_start(toggle_button, False, True)
+    self.__hbox.pack_start(toggle_button, True, True)
     self.__area.set_size_request(-1, self.get_height())
 
   def get_height(self):
@@ -110,6 +110,7 @@ class ToggleControlMaemo5(AbstractToggleControl):
     pa = hildon.PannableArea()
     pa.set_property('mov-mode', hildon.MOVEMENT_MODE_BOTH)
     pa.set_property('center-on-child-focus', True)
+    pa.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
     return pa
 
   def create_button(self, text='', group=None):
